@@ -21,10 +21,10 @@ try:
 except ImportError:
     import importlib_metadata
 
-__version__ = importlib_metadata.version('lazr.batchnavigator')
+__version__ = importlib_metadata.version("lazr.batchnavigator")
 
 # While we generally frown on "*" imports, this, combined with the fact we
 # only test code from this module, means that we can verify what has been
 # exported.
-from lazr.batchnavigator._batchnavigator import *
-from lazr.batchnavigator._batchnavigator import __all__
+from lazr.batchnavigator._batchnavigator import *  # noqa: F401, F403
+from lazr.batchnavigator._batchnavigator import __all__  # noqa: F401
