@@ -14,13 +14,14 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with lazr.batchnavigator. If not, see <http://www.gnu.org/licenses/>.
 
-from zope.interface import Interface, Attribute
-
-__metaclass__ = type
+from zope.interface import Attribute, Interface
 
 
 class InvalidBatchSizeError(AssertionError):
-    """Received a batch parameter that was invalid (e.g. exceeds our configured max size)."""
+    """Received a batch parameter that was invalid
+
+    (e.g. exceeds our configured max size).
+    """
 
 
 class IRangeFactory(Interface):
@@ -38,7 +39,7 @@ class IRangeFactory(Interface):
         :return: A tuple of bytestrings suitable for inclusion in URLs.
         """
 
-    def getSlice(size, endpoint_memo='', forwards=True):
+    def getSlice(size, endpoint_memo="", forwards=True):
         """Returns a slice of the results starting after endpoint_memo.
 
         Note that endpoint_memo should be a simple string and is untrusted.
@@ -70,7 +71,8 @@ class IRangeFactory(Interface):
 
         The value does not have to be accurate; it should only be
         used for informational purposes.
-        """)
+        """
+    )
 
 
 class IBatchNavigator(Interface):
@@ -79,7 +81,8 @@ class IBatchNavigator(Interface):
     batch = Attribute("The IBatch for which navigation links are provided.")
 
     heading = Attribute(
-        "The heading describing the kind of objects in the batch.")
+        "The heading describing the kind of objects in the batch."
+    )
 
     def setHeadings(singular, plural):
         """Set the heading for singular and plural results."""
@@ -92,9 +95,16 @@ class IBatchNavigator(Interface):
 
 
 class IBatchNavigatorFactory(Interface):
-    def __call__(results, request, start=0, size=None, callback=None,
-                 transient_parameters=None, force_start=False,
-                 range_factory=None):
+    def __call__(
+        results,
+        request,
+        start=0,
+        size=None,
+        callback=None,
+        transient_parameters=None,
+        force_start=False,
+        range_factory=None,
+    ):
         """Constructs an `IBatchNavigator` instance.
 
         :param results: is an iterable of results.
