@@ -17,16 +17,18 @@
 
 import unittest
 
-from lazr.batchnavigator.tests import (
-    test_docs,
-    )
+from lazr.batchnavigator.tests import test_docs
+
 
 def test_suite():
     # Discovery would be nice, but needs python2.7 for use with subunit &
     # testrepository.
     result = unittest.TestSuite()
     result.addTests(test_docs.additional_tests())
-    modules = ['batchnavigator', 'z3batching']
-    result.addTests(unittest.TestLoader().loadTestsFromNames([
-        'lazr.batchnavigator.tests.test_' + name for name in modules]))
+    modules = ["batchnavigator", "z3batching"]
+    result.addTests(
+        unittest.TestLoader().loadTestsFromNames(
+            ["lazr.batchnavigator.tests.test_" + name for name in modules]
+        )
+    )
     return result
