@@ -15,22 +15,20 @@
 # along with lazr.batchnavigator. If not, see <http://www.gnu.org/licenses/>.
 "Test harness for doctests."
 
-from __future__ import print_function
 
-__metaclass__ = type
 __all__ = [
-    'load_tests',
-    ]
+    "load_tests",
+]
 
 import atexit
 import doctest
 import os
+
 import pkg_resources
 
 DOCTEST_FLAGS = (
-    doctest.ELLIPSIS |
-    doctest.NORMALIZE_WHITESPACE |
-    doctest.REPORT_NDIFF)
+    doctest.ELLIPSIS | doctest.NORMALIZE_WHITESPACE | doctest.REPORT_NDIFF
+)
 
 
 def test_raises(exc_class, method, *args, **kwargs):
@@ -48,18 +46,26 @@ def load_tests(loader, tests, pattern):
     """Load all the doctests."""
     atexit.register(pkg_resources.cleanup_resources)
     doctest_files = []
-    if pkg_resources.resource_exists('lazr.batchnavigator', 'docs'):
+    if pkg_resources.resource_exists("lazr.batchnavigator", "docs"):
         for name in pkg_resources.resource_listdir(
-                'lazr.batchnavigator', 'docs'):
-            if name.endswith('.rst'):
+            "lazr.batchnavigator", "docs"
+        ):
+            if name.endswith(".rst"):
                 doctest_files.append(
                     os.path.abspath(
                         pkg_resources.resource_filename(
-                            'lazr.batchnavigator', 'docs/%s' % name)))
-    tests.addTest(doctest.DocFileSuite(
-        *doctest_files, module_relative=False, optionflags=DOCTEST_FLAGS,
-        globs={
-            "print_function": print_function,
-            "test_raises": test_raises,
-            }))
+                            "lazr.batchnavigator", "docs/%s" % name
+                        )
+                    )
+                )
+    tests.addTest(
+        doctest.DocFileSuite(
+            *doctest_files,
+            module_relative=False,
+            optionflags=DOCTEST_FLAGS,
+            globs={
+                "test_raises": test_raises,
+            },
+        )
+    )
     return tests
