@@ -16,33 +16,35 @@
 import operator
 import unittest
 
-from zope.interface.verify import verifyObject, verifyClass
+from zope.interface.verify import verifyClass, verifyObject
 
-from lazr.batchnavigator.z3batching.batch import (
-    _Batch,
-    BATCH_SIZE,
-    _PartialBatch,
-    )
-from lazr.batchnavigator.z3batching.interfaces import IBatch
 from lazr.batchnavigator import ListRangeFactory
+from lazr.batchnavigator.z3batching.batch import (
+    BATCH_SIZE,
+    _Batch,
+    _PartialBatch,
+)
+from lazr.batchnavigator.z3batching.interfaces import IBatch
 
 
 class ListWithExplosiveLen(list):
     """A list subclass that doesn't like its len() being called."""
+
     def __len__(self):
         raise RuntimeError
 
 
 class ListAllergicToNegativeIndexes(list):
     """A list subclass that doesn't like negative indexes."""
+
     def __getitem__(self, key):
         if isinstance(key, slice):
             if key.start < 0 or key.stop < 0:
-                raise RuntimeError('Negative indexes are not allowed.')
+                raise RuntimeError("Negative indexes are not allowed.")
         elif isinstance(key, int):
             if key < 0:
-                raise RuntimeError('Negative indexes are not allowed.')
-        return super(ListAllergicToNegativeIndexes, self).__getitem__(key)
+                raise RuntimeError("Negative indexes are not allowed.")
+        return super().__getitem__(key)
 
 
 class ListWithIncorrectLength(list):
@@ -59,8 +61,9 @@ class ListWithIncorrectLength(list):
     can be used in tests to ensure that result sets with bad length
     information are processed properly.
     """
+
     def __init__(self, length, data=[]):
-        super(ListWithIncorrectLength, self).__init__(data)
+        super().__init__(data)
         self._length = length
 
     def __len__(self):
@@ -74,12 +77,12 @@ class ListWithIncorrectLength(list):
                 key = slice(max(0, len(self) + key.start), key.stop, key.step)
             if key.stop < 0:
                 key = slice(key.start, len(self) + key.stop, key.step)
-        return super(ListWithIncorrectLength, self).__getitem__(key)
+        return super().__getitem__(key)
 
 
 class RangeFactoryWithValueBasedEndpointMemos:
-    """A RangeFactory which uses data values from a batch as endpoint memos.
-    """
+    """A RangeFactory which uses data values from a batch as endpoint memos."""
+
     def __init__(self, results):
         self.results = results
 
@@ -89,11 +92,11 @@ class RangeFactoryWithValueBasedEndpointMemos:
 
     getEndpointMemosFromSlice = getEndpointMemos
 
-    def getSlice(self, size, endpoint_memo='', forwards=True):
+    def getSlice(self, size, endpoint_memo="", forwards=True):
         """See `IRangeFactory`."""
         if size == 0:
             return []
-        if endpoint_memo == '':
+        if endpoint_memo == "":
             if forwards:
                 return self.results[:size]
             else:
@@ -103,13 +106,15 @@ class RangeFactoryWithValueBasedEndpointMemos:
 
         if forwards:
             index = 0
-            while (index < len(self.results) and
-                   endpoint_memo >= self.results[index]):
+            while (
+                index < len(self.results)
+                and endpoint_memo >= self.results[index]
+            ):
                 index += 1
-            return self.results[index:index+size]
+            return self.results[index : index + size]
         else:
             index = len(self.results) - 1
-            while (index >= 0 and endpoint_memo < self.results[index]):
+            while index >= 0 and endpoint_memo < self.results[index]:
                 index -= 1
             if index < 0:
                 return []
@@ -145,7 +150,7 @@ class TestingInfrastructureTest(unittest.TestCase):
         # For some of the tests we want to be sure len() of the underlying
         # collection is never called, so we've created a subclass of list that
         # raises an exception if asked for its length.
-        self.assertRaises(RuntimeError, len, ListWithExplosiveLen([1,2,3]))
+        self.assertRaises(RuntimeError, len, ListWithExplosiveLen([1, 2, 3]))
 
     def test_ListAllergicToNegativeIndexes(self):
         # Some of the tests want to show that the underlying collection is
@@ -153,12 +158,35 @@ class TestingInfrastructureTest(unittest.TestCase):
         # that raises an exception if accessed in that way.
         self.assertRaises(
             RuntimeError,
-            operator.getitem, ListAllergicToNegativeIndexes([1,2,3]), -1)
+            operator.getitem,
+            ListAllergicToNegativeIndexes([1, 2, 3]),
+            -1,
+        )
 
     def test_ListWithIncorrectLength(self):
         # Calling len(ListWithIncorrectLength) returns a bogus value.
-        self.assertEqual(0, len(ListWithIncorrectLength(0, [1,])))
-        self.assertEqual(2, len(ListWithIncorrectLength(2, [1,])))
+        self.assertEqual(
+            0,
+            len(
+                ListWithIncorrectLength(
+                    0,
+                    [
+                        1,
+                    ],
+                )
+            ),
+        )
+        self.assertEqual(
+            2,
+            len(
+                ListWithIncorrectLength(
+                    2,
+                    [
+                        1,
+                    ],
+                )
+            ),
+        )
         # Slicing works for positive indexes, even if len() returns a too
         # small value.
         weird_list = ListWithIncorrectLength(2, [0, 1, 2, 3])
@@ -177,42 +205,50 @@ class TestingInfrastructureTest(unittest.TestCase):
     def test_RangeFactoryWithValueBased_getEndpointMemos(self):
         data = [str(value) for value in range(10)]
         self.assertEqual(
-            ['0', '1', '2', '3', '4', '5', '6', '7', '8', '9'], data)
+            ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"], data
+        )
         factory = RangeFactoryWithValueBasedEndpointMemos(data)
         # The endpoint memo values are the values of the first and last
         # elelemnt of a batch.
         batch = data[:3]
-        self.assertEqual(('0', '2'), factory.getEndpointMemos(batch))
+        self.assertEqual(("0", "2"), factory.getEndpointMemos(batch))
         batch = data[4:8]
-        self.assertEqual(('4', '7'), factory.getEndpointMemos(batch))
+        self.assertEqual(("4", "7"), factory.getEndpointMemos(batch))
         # getSlice() called with an empty memo value returns the
         # first elements if forwards is True...
         self.assertEqual(
-            ['0', '1', '2'],
-            factory.getSlice(size=3, endpoint_memo='', forwards=True))
+            ["0", "1", "2"],
+            factory.getSlice(size=3, endpoint_memo="", forwards=True),
+        )
         # ...and the last elements if forwards is False.
         self.assertEqual(
-            ['9', '8', '7'],
-            factory.getSlice(size=3, endpoint_memo='', forwards=False))
+            ["9", "8", "7"],
+            factory.getSlice(size=3, endpoint_memo="", forwards=False),
+        )
         # A forwards slice starts with a value larger than the
         # given memo value.
         self.assertEqual(
-            ['6', '7'],
-            factory.getSlice(size=2, endpoint_memo='5', forwards=True))
+            ["6", "7"],
+            factory.getSlice(size=2, endpoint_memo="5", forwards=True),
+        )
         # A backwards slice starts with a value smaller than the
         # given memo value.
         self.assertEqual(
-            ['4', '3'],
-            factory.getSlice(size=2, endpoint_memo='5', forwards=False))
+            ["4", "3"],
+            factory.getSlice(size=2, endpoint_memo="5", forwards=False),
+        )
         # A slice is smaller than requested if the end of the results
         # is reached.
         self.assertEqual(
-            ['8', '9'],
-            factory.getSlice(size=3, endpoint_memo='7', forwards=True))
+            ["8", "9"],
+            factory.getSlice(size=3, endpoint_memo="7", forwards=True),
+        )
         self.assertEqual(
-            [], factory.getSlice(size=3, endpoint_memo='A', forwards=True))
+            [], factory.getSlice(size=3, endpoint_memo="A", forwards=True)
+        )
         self.assertEqual(
-            [], factory.getSlice(size=3, endpoint_memo=' ', forwards=False))
+            [], factory.getSlice(size=3, endpoint_memo=" ", forwards=False)
+        )
 
 
 class RecordingFactory(ListRangeFactory):
@@ -221,32 +257,54 @@ class RecordingFactory(ListRangeFactory):
         self.calls = []
 
     def getEndpointMemos(self, batch):
-        self.calls.append('getEndpointMemos')
+        self.calls.append("getEndpointMemos")
         return ListRangeFactory.getEndpointMemos(self, batch)
 
     def getSlice(self, size, memo, forwards):
-        self.calls.append(('getSlice', size, memo, forwards))
+        self.calls.append(("getSlice", size, memo, forwards))
         return ListRangeFactory.getSlice(self, size, memo, forwards)
 
 
 class BatchTest(unittest.TestCase):
-
     def getData(self):
-        return ['one', 'two', 'three', 'four', 'five', 'six',
-                'seven', 'eight', 'nine', 'ten']
+        return [
+            "one",
+            "two",
+            "three",
+            "four",
+            "five",
+            "six",
+            "seven",
+            "eight",
+            "nine",
+            "ten",
+        ]
 
     def test_Interface(self):
         self.assertTrue(IBatch.providedBy(self.getBatch()))
 
-    def getBatch(self, start=0, size=None, range_forwards=None,
-                 range_memo=None):
-        return _Batch(self.getData(), ListRangeFactory(self.getData()), start,
-            size, range_forwards, range_memo)
+    def getBatch(
+        self, start=0, size=None, range_forwards=None, range_memo=None
+    ):
+        return _Batch(
+            self.getData(),
+            ListRangeFactory(self.getData()),
+            start,
+            size,
+            range_forwards,
+            range_memo,
+        )
 
     def getRecordingBatch(self, start=0, size=None, memo=None, forwards=True):
         range_factory = RecordingFactory(self.getData())
-        batch = _Batch(range_factory.results, range_factory, start=start,
-            size=size, range_forwards=forwards, range_memo=memo)
+        batch = _Batch(
+            range_factory.results,
+            range_factory,
+            start=start,
+            size=size,
+            range_forwards=forwards,
+            range_memo=memo,
+        )
         return batch
 
     def test_constructor(self):
@@ -285,13 +343,13 @@ class BatchTest(unittest.TestCase):
 
     def test__getitem__(self):
         batch = self.getBatch(0, 3)
-        self.assertEqual(batch[0], 'one')
-        self.assertEqual(batch[1], 'two')
-        self.assertEqual(batch[2], 'three')
+        self.assertEqual(batch[0], "one")
+        self.assertEqual(batch[1], "two")
+        self.assertEqual(batch[2], "three")
         batch = self.getBatch(3, 3)
-        self.assertEqual(batch[0], 'four')
-        self.assertEqual(batch[1], 'five')
-        self.assertEqual(batch[2], 'six')
+        self.assertEqual(batch[0], "four")
+        self.assertEqual(batch[1], "five")
+        self.assertEqual(batch[2], "six")
         batch = self.getBatch(9, 3)
         self.assertRaises(IndexError, batch.__getitem__, 3)
 
@@ -304,9 +362,9 @@ class BatchTest(unittest.TestCase):
 
     def test__iter__(self):
         batch = self.getBatch(0, 3)
-        self.assertEqual(list(iter(batch)), ['one', 'two', 'three'])
+        self.assertEqual(list(iter(batch)), ["one", "two", "three"])
         batch = self.getBatch(9, 3)
-        self.assertEqual(list(iter(batch)), ['ten'])
+        self.assertEqual(list(iter(batch)), ["ten"])
         batch = self.getBatch(99, 3)
         self.assertEqual(list(iter(batch)), [])
 
@@ -321,14 +379,14 @@ class BatchTest(unittest.TestCase):
 
     def test__contains__(self):
         batch = self.getBatch(0, 3)
-        self.assertTrue(batch.__contains__('one'))
-        self.assertTrue(batch.__contains__('two'))
-        self.assertTrue(batch.__contains__('three'))
-        self.assertFalse(batch.__contains__('four'))
+        self.assertTrue(batch.__contains__("one"))
+        self.assertTrue(batch.__contains__("two"))
+        self.assertTrue(batch.__contains__("three"))
+        self.assertFalse(batch.__contains__("four"))
         batch = self.getBatch(6, 3)
-        self.assertFalse(batch.__contains__('one'))
-        self.assertTrue(batch.__contains__('seven'))
-        self.assertFalse(batch.__contains__('ten'))
+        self.assertFalse(batch.__contains__("one"))
+        self.assertTrue(batch.__contains__("seven"))
+        self.assertFalse(batch.__contains__("ten"))
 
     def test_last_batch_len_optimization(self):
         # If the current batch is known to be the last batch, then we can
@@ -356,25 +414,25 @@ class BatchTest(unittest.TestCase):
         """
         # first batch when we are at the beginning of the batch.
         first = self.getBatch(0, 3).firstBatch()
-        self.assertEqual(list(iter(first)), ['one', 'two', 'three'])
+        self.assertEqual(list(iter(first)), ["one", "two", "three"])
         # first batch when we are in the second set of items of the batch.
         first = self.getBatch(3, 3).firstBatch()
-        self.assertEqual(list(iter(first)), ['one', 'two', 'three'])
+        self.assertEqual(list(iter(first)), ["one", "two", "three"])
         # first batch when we are in the third set of items of the batch.
         first = self.getBatch(6, 3).firstBatch()
-        self.assertEqual(list(iter(first)), ['one', 'two', 'three'])
+        self.assertEqual(list(iter(first)), ["one", "two", "three"])
         # first batch when we are at the end of the batch.
         first = self.getBatch(9, 3).firstBatch()
-        self.assertEqual(list(iter(first)), ['one', 'two', 'three'])
+        self.assertEqual(list(iter(first)), ["one", "two", "three"])
         # first batch when we get a request for an out of range item.
         first = self.getBatch(99, 3).firstBatch()
-        self.assertEqual(list(iter(first)), ['one', 'two', 'three'])
+        self.assertEqual(list(iter(first)), ["one", "two", "three"])
 
     def test_nextBatch(self):
         next = self.getBatch(0, 3).nextBatch()
-        self.assertEqual(list(iter(next)), ['four', 'five', 'six'])
+        self.assertEqual(list(iter(next)), ["four", "five", "six"])
         nextnext = next.nextBatch()
-        self.assertEqual(list(iter(nextnext)), ['seven', 'eight', 'nine'])
+        self.assertEqual(list(iter(nextnext)), ["seven", "eight", "nine"])
         next = self.getBatch(9, 3).nextBatch()
         self.assertEqual(next, None)
         next = self.getBatch(99, 3).nextBatch()
@@ -382,7 +440,7 @@ class BatchTest(unittest.TestCase):
 
     def test_nextBatch__backwards_batching(self):
         # The "first backwards" batch has no next batch.
-        batch = self.getBatch(9, 3, range_forwards=False, range_memo='')
+        batch = self.getBatch(9, 3, range_forwards=False, range_memo="")
         self.assertTrue(batch.nextBatch() is None)
         # previous batches of this batch have a batch.
         batch = batch.prevBatch()
@@ -390,13 +448,13 @@ class BatchTest(unittest.TestCase):
 
     def test_prevBatch(self):
         prev = self.getBatch(9, 3).prevBatch()
-        self.assertEqual(list(iter(prev)), ['seven', 'eight', 'nine'])
+        self.assertEqual(list(iter(prev)), ["seven", "eight", "nine"])
         prevprev = prev.prevBatch()
-        self.assertEqual(list(iter(prevprev)), ['four', 'five', 'six'])
+        self.assertEqual(list(iter(prevprev)), ["four", "five", "six"])
         prev = self.getBatch(0, 3).prevBatch()
         self.assertEqual(prev, None)
         prev = self.getBatch(2, 3).prevBatch()
-        self.assertEqual(list(iter(prev)), ['one', 'two', 'three'])
+        self.assertEqual(list(iter(prev)), ["one", "two", "three"])
 
         # If we create a batch that's out of range, and don't get its
         # length or any of its data, its previous batch will also be
@@ -414,19 +472,19 @@ class BatchTest(unittest.TestCase):
         """
         # last batch when we are at the beginning of the batch.
         last = self.getBatch(0, 3).lastBatch()
-        self.assertEqual(list(iter(last)), ['ten'])
+        self.assertEqual(list(iter(last)), ["ten"])
         # last batch when we are in the second set of items of the batch.
         last = self.getBatch(3, 3).lastBatch()
-        self.assertEqual(list(iter(last)), ['ten'])
+        self.assertEqual(list(iter(last)), ["ten"])
         # last batch when we are in the third set of items of the batch.
         last = self.getBatch(6, 3).lastBatch()
-        self.assertEqual(list(iter(last)), ['ten'])
+        self.assertEqual(list(iter(last)), ["ten"])
         # last batch when we are at the end of the batch.
         last = self.getBatch(9, 3).lastBatch()
-        self.assertEqual(list(iter(last)), ['ten'])
+        self.assertEqual(list(iter(last)), ["ten"])
         # last batch when we get a request for an out of range item.
         last = self.getBatch(99, 3).lastBatch()
-        self.assertEqual(list(iter(last)), ['ten'])
+        self.assertEqual(list(iter(last)), ["ten"])
 
         # We are going to test now the same, but when we get a request of 5
         # items per batch because we had a bug in the way we calculate the
@@ -436,28 +494,32 @@ class BatchTest(unittest.TestCase):
         # last batch when we are at the beginning of the batch.
         last = self.getBatch(0, 5).lastBatch()
         self.assertEqual(
-            list(iter(last)), ['six', 'seven', 'eight', 'nine', 'ten'])
+            list(iter(last)), ["six", "seven", "eight", "nine", "ten"]
+        )
         # last batch when we are in the second set of items of the batch.
         last = self.getBatch(5, 5).lastBatch()
         self.assertEqual(
-            list(iter(last)), ['six', 'seven', 'eight', 'nine', 'ten'])
+            list(iter(last)), ["six", "seven", "eight", "nine", "ten"]
+        )
         # last batch when we get a request for an out of range item.
         last = self.getBatch(99, 5).lastBatch()
         self.assertEqual(
-            list(iter(last)), ['six', 'seven', 'eight', 'nine', 'ten'])
+            list(iter(last)), ["six", "seven", "eight", "nine", "ten"]
+        )
 
     def test_batchRoundTrip(self):
         batch = self.getBatch(0, 3).nextBatch()
-        self.assertEqual(list(iter(batch.nextBatch().prevBatch())),
-                         list(iter(batch)))
+        self.assertEqual(
+            list(iter(batch.nextBatch().prevBatch())), list(iter(batch))
+        )
 
     def test_first_last(self):
         batch = self.getBatch(0, 3)
-        self.assertEqual(batch.first(), 'one')
-        self.assertEqual(batch.last(), 'three')
+        self.assertEqual(batch.first(), "one")
+        self.assertEqual(batch.last(), "three")
         batch = self.getBatch(9, 3)
-        self.assertEqual(batch.first(), 'ten')
-        self.assertEqual(batch.last(), 'ten')
+        self.assertEqual(batch.first(), "ten")
+        self.assertEqual(batch.last(), "ten")
         batch = self.getBatch(99, 3)
         self.assertRaises(IndexError, batch.first)
         self.assertRaises(IndexError, batch.last)
@@ -486,7 +548,7 @@ class BatchTest(unittest.TestCase):
         # a code path that avoids calling len() on the underlying collection.
         data = ListWithExplosiveLen(self.getData())
         batch = _Batch(data, ListRangeFactory(data), 0, 3)
-        next(iter(batch)) # Materialize the items.
+        next(iter(batch))  # Materialize the items.
         self.assertEqual(batch.trueSize, 3)
 
     def test_optimized_trueSize_of_last_batch(self):
@@ -494,7 +556,7 @@ class BatchTest(unittest.TestCase):
         # reports how many items are in the batch.
         data = ListWithExplosiveLen(self.getData())
         batch = _Batch(data, ListRangeFactory(data), 9, 3)
-        next(iter(batch)) # Materialize the items.
+        next(iter(batch))  # Materialize the items.
         self.assertEqual(batch.trueSize, 1)
 
     def test_startNumber(self):
@@ -521,69 +583,77 @@ class BatchTest(unittest.TestCase):
         self.assertEqual(batch.endNumber(), None)
 
     def test_sliced_list_uses_range_factory(self):
-        batch = self.getRecordingBatch(memo='', forwards=False)
+        batch = self.getRecordingBatch(memo="", forwards=False)
         list(batch)
-        self.assertEqual([('getSlice', 10, '', False)], batch.range_factory.calls)
+        self.assertEqual(
+            [("getSlice", 10, "", False)], batch.range_factory.calls
+        )
 
     def test_firstBatch_generates_memo_None(self):
-        batch = self.getRecordingBatch(start=3, size=3, memo='3')
+        batch = self.getRecordingBatch(start=3, size=3, memo="3")
         first = batch.firstBatch()
-        self.assertEqual('', first.range_memo)
+        self.assertEqual("", first.range_memo)
         self.assertEqual(True, first.range_forwards)
         self.assertEqual(0, first.start)
         self.assertEqual(3, first.size)
-        self.assertEqual(['one', 'two', 'three'], list(first))
+        self.assertEqual(["one", "two", "three"], list(first))
 
     def test_lastBatch_generates_memo_None_backwards(self):
-        batch = self.getRecordingBatch(start=3, size=3, memo='3')
+        batch = self.getRecordingBatch(start=3, size=3, memo="3")
         last = batch.lastBatch()
-        self.assertEqual('', last.range_memo)
+        self.assertEqual("", last.range_memo)
         self.assertEqual(False, last.range_forwards)
         # len() is known, and size() is known, so the last batch starts at
         # len-size
         self.assertEqual(9, last.start)
         self.assertEqual(3, last.size)
-        self.assertEqual(['ten'], list(last))
+        self.assertEqual(["ten"], list(last))
 
     def test_nextBatch_generates_upper_memo(self):
-        batch = self.getRecordingBatch(start=3, size=3, memo='3')
+        batch = self.getRecordingBatch(start=3, size=3, memo="3")
         next = batch.nextBatch()
-        self.assertEqual('6', next.range_memo)
+        self.assertEqual("6", next.range_memo)
         self.assertEqual(True, next.range_forwards)
         self.assertEqual(6, next.start)
         self.assertEqual(3, next.size)
-        self.assertEqual(['seven', 'eight', 'nine'], list(next))
+        self.assertEqual(["seven", "eight", "nine"], list(next))
 
     def test_prevBatch_generates_lower_memo_backwards(self):
-        batch = self.getRecordingBatch(start=6, size=3, memo='3')
+        batch = self.getRecordingBatch(start=6, size=3, memo="3")
         prev = batch.prevBatch()
-        self.assertEqual('6', prev.range_memo)
+        self.assertEqual("6", prev.range_memo)
         self.assertEqual(False, prev.range_forwards)
         # len() is known, and size() is known, so the prev batch starts at
         # len-size
         self.assertEqual(3, prev.start)
         self.assertEqual(3, prev.size)
-        self.assertEqual(['four', 'five', 'six'], list(prev))
+        self.assertEqual(["four", "five", "six"], list(prev))
 
     def test_backwards_memo_inside_first_batch(self):
         # If data is retrieved backwards from the memo point and if
         # there is less data available than requested, additional
         # data stored "after the endpoint" is returned.
         batch = self.getRecordingBatch(start=0, size=5, memo=3, forwards=False)
-        self.assertEqual(['one', 'two', 'three', 'four', 'five'], list(batch))
+        self.assertEqual(["one", "two", "three", "four", "five"], list(batch))
 
     def test_trueSize__with_bad_list_length(self):
         # Even if the len(resultset) claims to have only 2 elements,
         # batches starting at offsets 1 and 2 have two elements.
         weird_list = ListWithIncorrectLength(2, [0, 1, 2, 3])
         batch = _Batch(
-            weird_list, range_factory=ListRangeFactory(weird_list),
-            size=2, start=1)
+            weird_list,
+            range_factory=ListRangeFactory(weird_list),
+            size=2,
+            start=1,
+        )
         self.assertEqual(2, batch.trueSize)
         self.assertEqual([1, 2, 3], batch.sliced_list)
         batch = _Batch(
-            weird_list, range_factory=ListRangeFactory(weird_list),
-            size=2, start=2)
+            weird_list,
+            range_factory=ListRangeFactory(weird_list),
+            size=2,
+            start=2,
+        )
         self.assertEqual(2, batch.trueSize)
         self.assertEqual([2, 3], batch.sliced_list)
 
@@ -592,8 +662,8 @@ class BatchTest(unittest.TestCase):
         # indicates that there should not be a next batch.
         weird_list = ListWithIncorrectLength(3, [0, 1, 2, 3, 4])
         batch = _Batch(
-            weird_list, range_factory=ListRangeFactory(weird_list),
-            size=3)
+            weird_list, range_factory=ListRangeFactory(weird_list), size=3
+        )
         self.assertTrue(batch.nextBatch() is not None)
 
     def test_nextBatch__bad_results_length(self):
@@ -601,8 +671,13 @@ class BatchTest(unittest.TestCase):
         # batch.nextBatch() is not None
         weird_list = ListWithIncorrectLength(6, [0, 1, 2, 3, 4, 5, 6])
         batch = _Batch(
-            weird_list, range_factory=ListRangeFactory(weird_list),
-            size=3, range_memo='3', start=3, range_forwards=True)
+            weird_list,
+            range_factory=ListRangeFactory(weird_list),
+            size=3,
+            range_memo="3",
+            start=3,
+            range_forwards=True,
+        )
         self.assertEqual([3, 4, 5, 6], batch.sliced_list)
         self.assertEqual([6], batch.nextBatch().sliced_list)
 
@@ -613,8 +688,13 @@ class BatchTest(unittest.TestCase):
         range_factory = RangeFactoryWithValueBasedEndpointMemos(data)
         # We create the first backwards.
         batch = _Batch(
-            data, range_factory=range_factory, size=3, range_memo='',
-            start=3, range_forwards=False)
+            data,
+            range_factory=range_factory,
+            size=3,
+            range_memo="",
+            start=3,
+            range_forwards=False,
+        )
         self.assertEqual([4, 5, 6], batch.sliced_list)
         self.assertEqual(3, batch.start)
         # The previous batch is now the first batch.
@@ -630,9 +710,13 @@ class BatchTest(unittest.TestCase):
         data = [0, 1, 2, 3, 4, 5, 6]
         range_factory = RangeFactoryWithValueBasedEndpointMemos(data)
         new_batch = _Batch(
-            data, range_factory=range_factory, size=3,
-            range_memo=batch.range_memo, start=batch.start,
-            range_forwards=False)
+            data,
+            range_factory=range_factory,
+            size=3,
+            range_memo=batch.range_memo,
+            start=batch.start,
+            range_forwards=False,
+        )
         # the contents of the batch is still correct. (Note that the
         # value of the last does not matter, see _Batch.sliced_list().)
         self.assertEqual([1, 2, 3, 0], new_batch.sliced_list)
@@ -651,9 +735,14 @@ class BatchTest(unittest.TestCase):
         data = [str(value) for value in range(10)]
         range_factory = RangeFactoryWithValueBasedEndpointMemos(data)
         batch = _Batch(
-            data, range_factory=range_factory, size=3, range_memo='1',
-            start=1, range_forwards=False)
-        self.assertEqual(['0', '1', '2', '3'], batch.sliced_list)
+            data,
+            range_factory=range_factory,
+            size=3,
+            range_memo="1",
+            start=1,
+            range_forwards=False,
+        )
+        self.assertEqual(["0", "1", "2", "3"], batch.sliced_list)
 
     def test_PartialBatch(self):
         # PartialBatch implements the full IBatch interface.
@@ -688,7 +777,8 @@ class BatchTest(unittest.TestCase):
         # has_next_batch is True. When the parameter range_memo
         # is given, the value of start does not matter.
         batch = self.getBatch(
-            start=7, size=3, range_forwards=True, range_memo="6")
+            start=7, size=3, range_forwards=True, range_memo="6"
+        )
         self.assertTrue(batch.has_next_batch)
 
     def test_has_next_batch__forwards_with_memo_at_end(self):
@@ -696,7 +786,8 @@ class BatchTest(unittest.TestCase):
         # has_next_batch is False. When the parameter range_memo
         # is given, the value of start does not matter.
         batch = self.getBatch(
-            start=6, size=3, range_forwards=True, range_memo="7")
+            start=6, size=3, range_forwards=True, range_memo="7"
+        )
         self.assertFalse(batch.has_next_batch)
 
     def test_has_next_batch__forwards_without_memo_not_at_end(self):
@@ -718,7 +809,8 @@ class BatchTest(unittest.TestCase):
         # has_previous_batch is True. The value of start does not
         # matter.
         batch = self.getBatch(
-            start=0, size=3, range_forwards=False, range_memo="4")
+            start=0, size=3, range_forwards=False, range_memo="4"
+        )
         self.assertTrue(batch.has_previous_batch)
 
     def test_has_previous_batch__backwards_with_memo_at_end(self):
@@ -726,7 +818,8 @@ class BatchTest(unittest.TestCase):
         # has_previous_batch is False.The value of start does not
         # matter.
         batch = self.getBatch(
-            start=1, size=3, range_forwards=False, range_memo="3")
+            start=1, size=3, range_forwards=False, range_memo="3"
+        )
         self.assertFalse(batch.has_previous_batch)
 
     def test_batch_gets_listlength_from_factory(self):
