@@ -18,6 +18,7 @@ $Id$
 from zope.interface import Attribute
 from zope.interface.common.mapping import IItemMapping
 
+
 class IBatch(IItemMapping):
     """A Batch represents a sub-list of the full enumeration.
 
@@ -66,12 +67,15 @@ class IBatch(IItemMapping):
         final index."""
 
     sliced_list = Attribute(
-        "A sliced list as returned by IRangeFactory.sliced_list.")
+        "A sliced list as returned by IRangeFactory.sliced_list."
+    )
 
     trueSize = Attribute("The actual size of this batch.")
 
     has_previous_batch = Attribute(
-        "True, if this batch has a predecessor, else False.")
+        "True, if this batch has a predecessor, else False."
+    )
 
     has_next_batch = Attribute(
-        "True, if this batch has a successor, else False.")
+        "True, if this batch has a successor, else False."
+    )
